<div class="ui selection dropdown ">
    <input name="{{ngName}}"
           type="hidden"
           value="{{selected}}"
            />

    <div class="text default">
        {{ngCollectionDefaultText}}
    </div>
    <i class="dropdown icon"></i>

    <div class="menu transition hidden">
        <div class="item"
             ng-if="showEmptyOption"
             ng-click="selectItem(null)"
             data-value="-1">
            {{ngNullName}}
         </div>

        <div class="item"
             data-value="{{option.value}}"
             ng-repeat="option in options"
             ng-click="selectItem(option)"
             >
            {{option.text}}
        </div>
    </div>
</div>
